@@ -32,7 +32,7 @@ class Threepio(object):
                     index for index, d in enumerate(
                         to_info['args']
                     )
-                    if d['name'] == from_arg.get(self.to_lang, {}).get('name')
+                    if d['name'] == from_arg.get(self.to_lang, None)
                 ),
                 None
             )
@@ -51,7 +51,7 @@ class Threepio(object):
                     index for index, d in enumerate(
                         to_info['args']
                     )
-                    if d['name'] == from_arg.get(self.to_lang, {}).get('name')
+                    if d['name'] == from_arg.get(self.to_lang, {})
                 ),
                 None
             )
@@ -68,16 +68,21 @@ class Threepio(object):
             self._normalize_func_name(cmd.function_name, self.from_lang)
         ]
         to_info = self.commands[self.to_lang][
-            self._normalize_func_name(from_info[self.to_lang], self.to_lang)
+            self._normalize_func_name(
+                from_info.get(self.to_lang),
+                self.to_lang
+            )
         ]
 
         attrs = to_info['attrs'][1:]
-        translated_cmd = self.framework
-
+        translated_cmd = None
         if lookup_command:
+            translated_cmd = self.framework
+
             while len(attrs) > 0:
                 translated_cmd = getattr(translated_cmd, attrs.pop(0))
 
         args, kwargs = self._order_args(cmd, from_info, to_info)
 
-        return Command(to_info['name'], args, kwargs, attrs, translated_cmd)
+        return Command(to_info['name'], args, kwargs, attrs=to_info['attrs'],
+                       exec_fn=translated_cmd)
