@@ -1,4 +1,7 @@
-import importlib.resources as pkg_resources
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    import importlib_resources as pkg_resources
 import json
 import static
 from typing import Callable
