@@ -23,7 +23,7 @@ def test_tf_torch_matmul(threepio_torch):
 
     c = threepio_torch.translate(
         Command('matmul', [tensor_a, tensor_b], {}),
-        True
+        lookup_command=True
     )
     r = c.execute_routine()
 
@@ -37,7 +37,7 @@ def test_torch_tf_matmul(threepio_tf):
 
     c = threepio_tf.translate(
         Command('matmul', [tensor_a, tensor_b], {}),
-        True
+        lookup_command=True
     )
     r = c.execute_routine()
 
